/* AxisAccessibility.java

	Purpose:
		
	Description:
		
	History:
		2:29 PM 2022/9/15, Created by jumperchen

Copyright (C) 2022 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Accessibility options for an axis.
 * <p>
 * Requires the accessibility module
 * to be loaded. For example,
 * <pre><code>
 * Library.setProperty("org.zkoss.chart.modules.accessibility", "true");
 * </code></pre>
 * @author jumperchen
 * @since 10.2.1.0
 */
public class AxisAccessibility extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		description,
		enabled,
		rangeDescription
	}

	/**
	 * Returns the description for an axis to expose to screen reader users.
	 * <p>Default: {@code null}</p>
	 */
	public String getDescription() {
		return getAttr(Attrs.description, null).asString();
	}

	/**
	 * Sets the description for an axis to expose to screen reader users.
	 * <p>Default: {@code null}</p>
	 */
	public void setDescription(String description) {
		setAttr(Attrs.description, description);
	}

	/**
	 * Returns whether to enable axis accessibility features, including axis information
	 * in the screen reader information region. If this is disabled on the xAxis,
	 * the x values are not exposed to screen readers for the individual data points by default.
	 * <p>Default: null</p>
	 */
	public Boolean isEnabled() {
		return getAttr(Attrs.enabled, null).asBoolean();
	}

	/**
	 * Sets whether to enable axis accessibility features, including axis information
	 * in the screen reader information region. If this is disabled on the xAxis,
	 * the x values are not exposed to screen readers for the individual data points by default.
	 */
	public void setEnabled(boolean enabled) {
		setAttr(Attrs.enabled, enabled);
	}

	/**
	 * Returns the range description for an axis. Overrides the default range description.
	 * Set to empty to disable range description for this axis.
	 * <p>Default: {@code null}
	 */
	public String getRangeDescription() {
		return getAttr(Attrs.rangeDescription, null).asString();
	}

	/**
	 * Sets the range description for an axis. Overrides the default range description.
	 * Set to empty to disable range description for this axis.
	 * <p>Default: {@code null}
	 */
	public void setRangeDescription(String rangeDescription) {
		setAttr(Attrs.rangeDescription, rangeDescription);
	}
}
