/* KeyboardNavigation.java

	Purpose:
		
	Description:
		
	History:
		12:09 PM 2022/9/19, Created by jumperchen

Copyright (C) 2022 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import java.util.List;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An options for keyboard navigation.
 * @author jumperchen
 * @since 10.2.1.0
 */
public class KeyboardNavigation extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		enabled,
		focusBorder,
		order,
		seriesNavigation,
		wrapAround
	}

	/**
	 * Returns whether to enable keyboard navigation for the chart.
	 * <p> Default: {@code true}
	 */
	public boolean isEnabled() {
		return getAttr(Attrs.enabled, true).asBoolean();
	}

	/**
	 * Sets whether to enable keyboard navigation for the chart.
	 * <p> Default: {@code true}
	 */
	public void setEnabled(boolean enabled) {
		setAttr(Attrs.enabled, enabled);
	}

	/**
	 * Returns an options for the focus border drawn around elements while navigating
	 * through them, or create a new one.
	 * <p>Default: an instance of {@link FocusBorder}
	 */
	public FocusBorder getFocusBorder() {
		return (FocusBorder) getAttr(Attrs.focusBorder,
				FocusBorder.class).asValue();
	}

	/**
	 * Sets an options for the focus border drawn around elements while navigating
	 * through them, or create a new one.
	 */
	public void setFocusBorder(FocusBorder focusBorder) {
		setAttr(Attrs.focusBorder, focusBorder);
	}

	/**
	 * Returns the order of tab navigation in the chart. Determines which elements
	 * are tabbed to first.
	 * <p>Available elements are: {@code series}, {@code zoom}, {@code rangeSelector},
	 * {@code chartMenu}, {@code legend} and {@code container}. In addition, any
	 * custom components can be added here. Adding container first in order will
	 * make the keyboard focus stop on the chart container first, requiring the user
	 * to tab again to enter the chart.
	 * <p>Default: {@code null}
	 */
	public List<String> getOrder() {
		return (List<String>) getAttr(Attrs.order, null).asValue();
	}

	/**
	 * Sets the order of tab navigation in the chart. Determines which elements
	 * are tabbed to first.
	 * <p>Available elements are: {@code series}, {@code zoom}, {@code rangeSelector},
	 * {@code chartMenu}, {@code legend} and {@code container}. In addition, any
	 * custom components can be added here. Adding container first in order will
	 * make the keyboard focus stop on the chart container first, requiring the user
	 * to tab again to enter the chart.
	 */
	public void setOrder(List<String> order) {
		setAttr(Attrs.order, order);
	}

	/**
	 * Returns an options for the keyboard navigation of data points and series,
	 * or create a new one.
	 * <p>Default: an instance of {@link SeriesNavigation}
	 */
	public SeriesNavigation getSeriesNavigation() {
		return (SeriesNavigation) getAttr(Attrs.seriesNavigation,
				SeriesNavigation.class).asValue();
	}

	/**
	 * Sets an options for the keyboard navigation of data points and series,
	 * or create a new one.
	 */
	public void setSeriesNavigation(SeriesNavigation seriesNavigation) {
		setAttr(Attrs.seriesNavigation, seriesNavigation);
	}

	/**
	 * Return whether or not to wrap around when reaching the end of arrow-key navigation
	 * for an element in the chart.
	 * <p> Default: {@code true}
	 */
	public boolean isWrapAround() {
		return getAttr(Attrs.wrapAround, true).asBoolean();
	}

	/**
	 * Sets whether or not to wrap around when reaching the end of arrow-key navigation
	 * for an element in the chart.
	 */
	public void setWrapAround(boolean wrapAround) {
		setAttr(Attrs.wrapAround, wrapAround);
	}
}