/* LangAnnounceNewData.java

	Purpose:
		
	Description:
		
	History:
		10:26 AM 2022/9/20, Created by jumperchen

Copyright (C) 2022 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Default announcement for new data in charts. If addPoint or addSeries is used,
 * and only one series/point is added, the {@code newPointAnnounce} and {@code newSeriesAnnounce}
 * strings are used. The {@code ...Single} versions will be used if there is only
 * one chart on the page, and the {@code ...Multiple} versions will be used if there
 * are multiple charts on the page. For all other new data events, the {@code newDataAnnounce}
 * string will be used.
 * @author jumperchen
 * @since 10.2.1.0
 */
public class LangAnnounceNewData extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		newDataAnnounce,
		newPointAnnounceMultiple,
		newPointAnnounceSingle,
		newSeriesAnnounceMultiple,
		newSeriesAnnounceSingle
	}

	/**
	 * <p>Default: {@code "Updated data for chart {chartTitle}"}
	 */
	public String getNewDataAnnounce() {
		return getAttr(Attrs.newDataAnnounce,
				"Updated data for chart {chartTitle}").asString();
	}

	public void setNewDataAnnounce(String newDataAnnounce) {
		setAttr(Attrs.newDataAnnounce, newDataAnnounce);
	}

	/**
	 * <p>Default: {@code "New data point in chart {chartTitle}: {pointDesc}"}
	 */
	public String getNewPointAnnounceMultiple() {
		return getAttr(Attrs.newPointAnnounceMultiple,
				"New data point in chart {chartTitle}: {pointDesc}").asString();
	}

	public void setNewPointAnnounceMultiple(String newPointAnnounceMultiple) {
		setAttr(Attrs.newPointAnnounceMultiple, newPointAnnounceMultiple);
	}

	/**
	 * <p>Default: {@code "New data point: {pointDesc}"}
	 */
	public String getNewPointAnnounceSingle() {
		return getAttr(Attrs.newPointAnnounceSingle,
				"New data point: {pointDesc}").asString();
	}

	public void setNewPointAnnounceSingle(String newPointAnnounceSingle) {
		setAttr(Attrs.newPointAnnounceSingle, newPointAnnounceSingle);
	}

	/**
	 * <p>Default: {@code "New data series in chart {chartTitle}: {seriesDesc}"}
	 */
	public String getNewSeriesAnnounceMultiple() {
		return getAttr(Attrs.newSeriesAnnounceMultiple,
				"New data series in chart {chartTitle}: {seriesDesc}").asString();
	}

	public void setNewSeriesAnnounceMultiple(String newSeriesAnnounceMultiple) {
		setAttr(Attrs.newSeriesAnnounceMultiple, newSeriesAnnounceMultiple);
	}

	/**
	 * <p>Default: {@code "New data series: {seriesDesc}"}
	 */
	public String getNewSeriesAnnounceSingle() {
		return getAttr(Attrs.newSeriesAnnounceSingle,
				"New data series: {seriesDesc}").asString();
	}

	public void setNewSeriesAnnounceSingle(String newSeriesAnnounceSingle) {
		setAttr(Attrs.newSeriesAnnounceSingle, newSeriesAnnounceSingle);
	}
}
