/* LangScreenReaderSection.java

	Purpose:
		
	Description:
		
	History:
		11:34 AM 2022/9/20, Created by jumperchen

Copyright (C) 2022 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Language options for the screen reader information sections added before and after the charts.
 * @author jumperchen
 * @since 10.2.1.0
 */
public class LangScreenReaderSection extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		afterRegionLabel,
		annotations,
		beforeRegionLabel,
		endOfChartMarker
	}

	/**
	 * <p>Default: {@code ""}
	 */
	public String getAfterRegionLabel() {
		return getAttr(Attrs.afterRegionLabel, "").asString();
	}

	public void setAfterRegionLabel(String afterRegionLabel) {
		setAttr(Attrs.afterRegionLabel, afterRegionLabel);
	}

	/**
	 * Returns language options for annotation descriptions. If null, create a new
	 * one.
	 */
	public LangScreenReaderSectionAnnotations getAnnotations() {
		return (LangScreenReaderSectionAnnotations) getAttr(
				Attrs.annotations, LangScreenReaderSectionAnnotations.class).asValue();
	}

	/**
	 * Sets language options for annotation descriptions.
	 */
	public void setAnnotations(LangScreenReaderSectionAnnotations annotations) {
		setAttr(Attrs.annotations, annotations);
	}

	/**
	 * <p>Default: {@code ""}
	 */
	public String getBeforeRegionLabel() {
		return getAttr(Attrs.beforeRegionLabel, "").asString();
	}

	public void setBeforeRegionLabel(String beforeRegionLabel) {
		setAttr(Attrs.beforeRegionLabel, beforeRegionLabel);
	}

	/**
	 * Returns label for the end of the chart. Announced by screen readers.
	 * <p>Default: {@code "End of interactive chart."}
	 */
	public String getEndOfChartMarker() {
		return getAttr(Attrs.endOfChartMarker, "End of interactive chart.").asString();
	}

	/**
	 * Sets label for the end of the chart. Announced by screen readers.
	 */
	public void setEndOfChartMarker(String endOfChartMarker) {
		setAttr(Attrs.endOfChartMarker, endOfChartMarker);
	}
}
