/* LangSeries.java

	Purpose:
		
	Description:
		
	History:
		11:42 AM 2022/9/20, Created by jumperchen

Copyright (C) 2022 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Lang configuration for different series types. For more dynamic control over
 * the series element descriptions, see {@link AccessibilitySeries#getDescriptionFormatter()}.
 * @author jumperchen
 * @since 10.2.1.0
 */
public class LangSeries extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		description,
		nullPointValue,
		pointAnnotationsDescription,
		summary,
		xAxisDescription,
		yAxisDescription
	}

	/**
	 * Returns user supplied description text. This is added in the point comment description by default if present.
	 * <p>Default: {@code "Bar chart with {numSeries} data series."}
	 */
	public String getDescription() {
		return getAttr(Attrs.description, "{description}").asString();
	}


	/**
	 * Sets user supplied description text. This is added in the point comment description by default if present.
	 */
	public void setDescription(String description) {
		setAttr(Attrs.description, description);
	}

	/**
	 * Returns the description for the value of null points.
	 * <p>Default: {@code "No value"}
	 */
	public String getNullPointValue() {
		return getAttr(Attrs.nullPointValue, "No value").asString();
	}


	/**
	 * Sets the description for the value of null points.
	 */
	public void setNullPointValue(String nullPointValue) {
		setAttr(Attrs.nullPointValue, nullPointValue);
	}

	/**
	 * Returns the description for annotations on a point, as it is made available to assistive technology.
	 * <p>Default: {@code "{Annotation: #each(annotations). }"}
	 */
	public String getPointAnnotationsDescription() {
		return getAttr(Attrs.pointAnnotationsDescription, "{Annotation: #each(annotations). }").asString();
	}

	/**
	 * Sets the description for annotations on a point, as it is made available to assistive technology.
	 */
	public void setPointAnnotationsDescription(
			String pointAnnotationsDescription) {
		setAttr(Attrs.pointAnnotationsDescription, pointAnnotationsDescription);
	}

	/**
	 * Returns lang configuration for the series main summary.
	 * If null, create a new one.
	 */
	public LangSeriesSummary getSummary() {
		return (LangSeriesSummary) getAttr(Attrs.summary, LangSeriesSummary.class).asValue();
	}

	/**
	 * Sets lang configuration for the series main summary.
	 */
	public void setSummary(LangSeriesSummary summary) {
		setAttr(Attrs.summary, summary);
	}

	/**
	 * Returns xAxis description for series if there are multiple xAxes in the chart.
	 * <p>Default: {@code "X axis, {name}"}
	 */
	public String getXAxisDescription() {
		return getAttr(Attrs.xAxisDescription, "X axis, {name}").asString();
	}

	/**
	 * Sets xAxis description for series if there are multiple xAxes in the chart.
	 */
	public void setXAxisDescription(String xAxisDescription) {
		setAttr(Attrs.xAxisDescription, xAxisDescription);
	}

	/**
	 * Returns yAxis description for series if there are multiple yAxes in the chart.
	 * <p>Default: {@code "Y axis, {name}"}
	 */
	public String getYAxisDescription() {
		return getAttr(Attrs.yAxisDescription, "Y axis, {name}").asString();
	}

	/**
	 * Sets yAxis description for series if there are multiple yAxes in the chart.
	 */
	public void setYAxisDescription(String yAxisDescription) {
		setAttr(Attrs.yAxisDescription, yAxisDescription);
	}
}
