/* LegendAccessibility.java

	Purpose:
		
	Description:
		
	History:
		5:59 PM 2022/9/19, Created by jumperchen

Copyright (C) 2022 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Options for configuring accessibility for the legend of the chart.
 * <p>
 * Requires the accessibility module
 * to be loaded. For example,
 * <pre><code>
 * Library.setProperty("org.zkoss.chart.modules.accessibility", "true");
 * </code></pre>
 * @author jumperchen
 * @since 10.2.1.0
 */
public class LegendAccessibility extends Optionable {

	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		enabled,
		keyboardNavigation
	}

	/**
	 * Returns whether to enable accessibility support for the legend.
	 * <p> Default: {@code true}
	 */
	public boolean isEnabled() {
		return getAttr(Attrs.enabled, true).asBoolean();
	}

	/**
	 * Sets whether to enable accessibility support for the legend.
	 * <p> Default: {@code true}
	 */
	public void setEnabled(boolean enabled) {
		setAttr(Attrs.enabled, enabled);
	}

	/**
	 * Returns options for keyboard navigation for the legend, or create new one.
	 * <p> Default: an instance of {@link LegendKeyboardNavigation}
	 */
	public LegendKeyboardNavigation getKeyboardNavigation() {
		return (LegendKeyboardNavigation) getAttr(Attrs.keyboardNavigation,
				KeyboardNavigation.class).asValue();
	}

	/**
	 * Sets options for keyboard navigation for the legend.
	 */
	public void setKeyboardNavigation(
			LegendKeyboardNavigation keyboardNavigation) {
		setAttr(Attrs.keyboardNavigation, keyboardNavigation);
	}
}
