/* PointAccessibility.java

	Purpose:
		
	Description:
		
	History:
		5:29 PM 2022/9/16, Created by jumperchen

Copyright (C) 2022 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Accessibility options for a point.
 * @author jumperchen
 * @since 10.2.1.0
 */
public class PointAccessibility extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		description, enabled
	}

	/**
	 * Returns the description of the data point, announced to screen readers.
	 * <p>Default: {@code null}</p>
	 */
	public String getDescription() {
		return getAttr(Attrs.description, null).asString();
	}

	/**
	 * Sets the description of the data point, announced to screen readers.
	 * <p>Default: {@code null}</p>
	 */
	public void setDescription(String description) {
		setAttr(Attrs.description, description);
	}

	/**
	 * Returns whether to disable accessibility functionality for a specific point.
	 * The point will not be included in keyboard navigation, and will not be exposed
	 * to assistive technology.
	 * <p>Default: null</p>
	 */
	public Boolean isEnabled() {
		return getAttr(Attrs.enabled, null).asBoolean();
	}

	/**
	 * Sets whether to disable accessibility functionality for a specific point.
	 * The point will not be included in keyboard navigation, and will not be exposed
	 * to assistive technology.
	 */
	public void setEnabled(boolean enabled) {
		setAttr(Attrs.enabled, enabled);
	}
}
