/* WindBarbPlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Thu Dec 05 16:16:42 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An option for windbarb plot
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class WindBarbPlotOptions extends ColumnPlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		dataGrouping, onSeries, vectorLength, xOffset, yOffset
	}

	/**
	 * Returns the data grouping options for the wind barbs, if any.
	 * Otherwise, create a new one.
	 */
	public WindBarbDataGrouping getDataGrouping() {
		WindBarbDataGrouping dataGrouping = (WindBarbDataGrouping) getAttr(Attrs.dataGrouping);
		if (dataGrouping == null) {
			dataGrouping = new WindBarbDataGrouping();
			setDataGrouping(dataGrouping);
		}
		return dataGrouping;
	}

	/**
	 * Sets the data grouping options for the wind barbs.
	 */
	public void setDataGrouping(WindBarbDataGrouping dataGrouping) {
		setAttr(Attrs.dataGrouping, dataGrouping);
	}

	/**
	 * Returns the id of another series in the chart that the wind barbs are projected on.
	 * When null, the wind symbols are drawn on the X axis, but offset up or down by the yOffset setting.
	 * <p>
	 * Default: null
	 */
	public String getOnSeries() {
		return getAttr(Attrs.onSeries, null).asString();
	}

	/**
	 * Sets the id of another series in the chart that the wind barbs are projected on.
	 * When null, the wind symbols are drawn on the X axis, but offset up or down by the yOffset setting.
	 */
	public void setOnSeries(String onSeries) {
		setAttr(Attrs.onSeries, onSeries);
	}

	/**
	 * Returns the pixel length of the stems.
	 * <p>
	 * Default: 20
	 */
	public Number getVectorLength() {
		return getAttr(Attrs.vectorLength, 20).asNumber();
	}

	/**
	 * Sets the pixel length of the stems.
	 */
	public void setVectorLength(Number vectorLength) {
		setAttr(Attrs.vectorLength, vectorLength);
	}

	/**
	 * Returns horizontal offset from the cartesian position, in pixels.
	 * When the chart is inverted, this option allows translation like yOffset in non inverted charts.
	 * <p>
	 * Default: 0
	 */
	public Number getXOffset() {
		return getAttr(Attrs.xOffset, 0).asNumber();
	}

	/**
	 * Sets horizontal offset from the cartesian position, in pixels.
	 * When the chart is inverted, this option allows translation like yOffset in non inverted charts.
	 */
	public void setXOffset(Number xOffset) {
		setAttr(Attrs.xOffset, xOffset);
	}

	/**
	 * Returns vertical offset from the cartesian position, in pixels.
	 * The default value makes sure the symbols don't overlap the X axis when onSeries is null,
	 * and that they don't overlap the linked series when onSeries is given.
	 * <p>
	 * Default: -20
	 */
	public Number getYOffset() {
		return getAttr(Attrs.yOffset, -20).asNumber();
	}

	/**
	 * Sets vertical offset from the cartesian position, in pixels.
	 * The default value makes sure the symbols don't overlap the X axis when onSeries is null,
	 * and that they don't overlap the linked series when onSeries is given.
	 */
	public void setYOffset(Number yOffset) {
		setAttr(Attrs.yOffset, yOffset);
	}
}
